@@ -132,7 +132,7 @@ class binance():
         query_string = urlencode(params)
         params['signature'] = hmac.new(self.API_SECRET.encode('utf-8'), query_string.encode('utf-8'), hashlib.sha256).hexdigest()
         headers = {'X-MBX-APIKEY': self.API_KEY}
-        url = urljoin('https://api.binance.com','/api/v3/openOrderList')
+        url = urljoin('https://api.binance.com','/api/v3/openOrders')
         response = requests.get(url, headers=headers, params=params).json()
         try:
             code = response['code']
@@ -153,7 +153,7 @@ class binance():
             'type':'LIMIT',
             'timeInForce':'GTC',
             'quantity':self.truncate(quantity,6),
-            'price':price,
+            'price':self.truncate(price,8),
             'timestamp': timestamp,
             'recvWindow':recvWindow,
         }
@@ -193,7 +193,7 @@ class binance():
             'type':'STOP_LOSS',
             'timeInForce':'GTC',
             'quantity':self.truncate(quantity,6),
-            'price':stopPrice,
+            'price':self.truncate(stopPrice,8),
             'timestamp': timestamp,
             'recvWindow':recvWindow,
         }
@@ -214,7 +214,7 @@ class binance():
             'type':'TAKE_PROFIT',
             'timeInForce':'GTC',
             'quantity':self.truncate(quantity,6),
-            'price':profitPrice,
+            'price':self.truncate(profitPrice,8),
             'timestamp': timestamp,
             'recvWindow':recvWindow,
         }
@@ -225,7 +225,41 @@ class binance():
         response = requests.post(url, headers=headers, params=params).text
         return response
 
-         
+    def query_order(self,symbol,orderid):
+        '''Function to query order data'''
+        timestamp = int(time.time() * 1000)
+        recvWindow=10000
+        params = {
+            'symbol':symbol,
+            'orderId':orderid,
+            'timestamp': timestamp,
+            'recvWindow':recvWindow,
+        }
+        query_string = urlencode(params)
+        params['signature'] = hmac.new(self.API_SECRET.encode('utf-8'), query_string.encode('utf-8'), hashlib.sha256).hexdigest()
+        headers = {'X-MBX-APIKEY': self.API_KEY}
+        url = urljoin('https://api.binance.com','/api/v3/order')
+        response = requests.post(url, headers=headers, params=params).text
+        return response
+        
+    def test_order(self):
+        '''Function to create market order'''
+        timestamp = int(time.time() * 1000)
+        recvWindow=10000
+        params = {
+            'symbol':'BTCEUR',
+            'side':'buy',
+            'type':'MARKET',
+            'quantity':1,
+            'timestamp': timestamp,
+            'recvWindow':recvWindow,
+        }
+        query_string = urlencode(params)
+        params['signature'] = hmac.new(self.API_SECRET.encode('utf-8'), query_string.encode('utf-8'), hashlib.sha256).hexdigest()
+        headers = {'X-MBX-APIKEY': self.API_KEY}
+        url = urljoin('https://api.binance.com','/api/v3/order/test')
+        response = requests.post(url, headers=headers, params=params).text
+        return response
    
 class kraken():
     
